@@ -697,7 +697,9 @@ class DataManager:
     def join_from_jinja_repo(self, inner_path: str, how: JoinLiterals = "left", frame_name=None,
                              jinja_parameters_dict: dict = None,
                              format_func_dict: FormatDict | dict = None, left_on: str | tuple = None,
-                             left_index: bool = False):
+                             left_index: bool = False,
+                             num_inserts_display_in_frame = 50,
+                             override_frame_jinja_repo_source: JinjaRepo = None):
 
         """
         This function joins the result of a jinja repo script to a DataManager object. Note that the `connection` and
@@ -729,7 +731,8 @@ class DataManager:
         else:
             _jinja_parameters_dict = jinja_parameters_dict
 
-        config = _get_config_from_master(inner_path, self.setup.jinja_repo_source)  # TODO replace with JinjaRepo.pull
+        _jinja_repo_source = override_frame_jinja_repo_source or self.setup.jinja_repo_source
+        config = _get_config_from_master(inner_path, _jinja_repo_source)  # TODO replace with JinjaRepo.pull
 
         if config["meta"]["population"]:
             raise ConfigError(f'expected population status is False script got: {config["meta"]['population']}')
@@ -744,14 +747,16 @@ class DataManager:
         else:
             rename_dict = None
 
-        con = self.setup.jinja_repo_source.conn_dict[config['meta']['connection']]
+        con = _jinja_repo_source.conn_dict[config['meta']['connection']]
 
         sql = self.resolve_dimension_jinja_repo_template(inner_path, right_on, jinja_parameters_dict,
-                                                         rename_columns_dict=rename_dict)
+                                                         rename_columns_dict=rename_dict,
+                                                         override_jinja_repo_source = _jinja_repo_source)
         df = query.execute_sql_string(sql, con)
 
         _frame_name = frame_name or config["meta"]["name"]
-        frame = meta._Frame(_frame_name, "JinjaRepo", df, sql=sql)
+        sql_truncated_inserts = query.truncate_sql_inserts(sql,num_inserts_display_in_frame)
+        frame = meta._Frame(_frame_name, "JinjaRepo", df, sql=sql_truncated_inserts)
 
         self._join_from_frame(frame, right_on, how, format_func_dict, None, None, False,
                               False)
@@ -886,7 +891,8 @@ class DataManager:
                              format_parameters_list: list = None,
                              frame_name: str = None, format_func_dict: FormatDict | dict = None,
                              left_on: str | tuple = None, right_on: str | tuple = None,
-                             left_index: bool = False, right_index: bool = False):
+                             left_index: bool = False, right_index: bool = False,
+                             num_inserts_display_in_frame = 50):
         """
 
         Inserts the records contained in the target population into a format SQL script template, this creates a script
@@ -975,7 +981,8 @@ class DataManager:
                                                      rename_columns_dict=_rename_dict)
         df = query.execute_sql_string(sql, connection)
 
-        frame = meta._Frame(_frame_name, "Format SQL", df, sql=sql)
+        sql_truncated_inserts = query.truncate_sql_inserts(sql, num_inserts_display_in_frame)
+        frame = meta._Frame(_frame_name, "Format SQL", df, sql=sql_truncated_inserts)
         self._join_from_frame(frame, on, how, format_func_dict, left_on, right_on, left_index,
                               right_index)
 
@@ -984,7 +991,8 @@ class DataManager:
                         jinja_parameters_dict: dict = None,
                         frame_name: str = None, format_func_dict: dict = None,
                         left_on: str | tuple = None, right_on: str | tuple = None,
-                        left_index: bool = False, right_index: bool = False):
+                        left_index: bool = False, right_index: bool = False,
+                        num_inserts_display_in_frame = 50):
 
         """
 
@@ -1071,7 +1079,8 @@ class DataManager:
                                                 rename_columns_dict=_rename_dict)
         df = query.execute_sql_string(sql, connection)
 
-        frame = meta._Frame(_frame_name, "Jinja", df, sql=sql)
+        sql_truncated_inserts = query.truncate_sql_inserts(sql, num_inserts_display_in_frame)
+        frame = meta._Frame(_frame_name, "Jinja", df, sql=sql_truncated_inserts)
         self._join_from_frame(frame, on, how, format_func_dict, left_on, right_on, left_index,
                               right_index)
 
@@ -1438,7 +1447,8 @@ class DataManager:
 
     def resolve_dimension_jinja_repo_template(self, inner_path: str, key: str | list | tuple,
                                               jinja_parameters_dict: dict, frame: str | int = None,
-                                              rename_columns_dict: dict | None = None) -> str:
+                                              rename_columns_dict: dict | None = None,
+                                              override_jinja_repo_source: JinjaRepo = None) -> str:
         """
         Resolves a dimension script from a jinja repository.
 
@@ -1453,7 +1463,7 @@ class DataManager:
             Rendered SQL script.
 
         """
-        jenv = JinjaRepo(self.setup.jinja_repo_source.root_dir)
+        jenv = override_jinja_repo_source or JinjaRepo(self.setup.jinja_repo_source.root_dir)
         jinja_parameters_dict = self._maybe_get_jinja_insert_dict(key, jinja_parameters_dict, frame,
                                                                   rename_columns_dict)
         sql = self._get_sql_from_jinja_template(jenv, inner_path, jinja_parameters_dict)
