@@ -31,3 +31,8 @@ class InsertError(Exception):
     """Inserts not correctly entered into sql script"""
     pass
 
+class GranularityError(Exception):
+    """Raised when the granularity of a dataframe changes unexpectedly, usually due to a join"""
+
+class MissingColumnError(KeyError):
+    """Function expects the dataframe to have a specific column, but it is not found"""
